@@ -204,7 +204,7 @@ bool AudioCodec::load(const char *name)
 #ifdef	W32
 	snprintf(path, sizeof(path), "%s/%s", Audio::getCodecPath(), name);
 #else
-	snprintf(path, sizeof(path), "%s/%s", CODEC_LIBPATH, name);
+	snprintf(path, sizeof(path), "%s/%s.codec", CODEC_LIBPATH, name);
 #endif
 #endif
 	return loadPlugin(path);
