@@ -32,7 +32,7 @@ void Tool::trim(char **argv)
 	unsigned long sum;
 	unsigned long count;
 	char target[PATH_MAX];
-	bool use;
+	bool use = false;
 	
 retry:
 	if(!*argv)
